
# Type: objectidentifier


A URI or CURIE that represents an object in the model.

URI: [meta:Objectidentifier](https://w3id.org/linkml/Objectidentifier)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **ElementIdentifier** |
| Representation | | str |

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Used for inheritence and type checking |

